@@ -61,6 +61,8 @@ setMethod(
 #' name for the OdbcConnect object returned from `dbConnect()`. However if the
 #' driver does not return a valid value it can be set manually with this
 #' parameter.
+#' @param attributes An S4 object of connection attributes that are passed
+#' prior to the connection being established.  See \link{ConnectionAttributes}.
 #' @param ... Additional ODBC keywords, these will be joined with the other
 #' arguments to form the final connection string.
 #' @param .connection_string A complete connection string, useful if you are
@@ -75,9 +77,10 @@ setMethod(
 #' The connection string keywords are driver dependent. The parameters
 #' documented here are common, but some drivers may not accept them. Please see
 #' the specific driver documentation for allowed parameters,
-#' 'https://www.connectionstrings.com' is also a useful resource of example
+#' \url{https://www.connectionstrings.com} is also a useful resource of example
 #' connection strings for a variety of databases.
 #' @aliases dbConnect
+#' @import rlang
 #' @export
 setMethod(
   "dbConnect", "OdbcDriver",
@@ -95,6 +98,7 @@ setMethod(
     uid = NULL,
     pwd = NULL,
     dbms.name = NULL,
+    attributes = NULL,
     .connection_string = NULL) {
 
     con <- OdbcConnection(
@@ -111,6 +115,7 @@ setMethod(
       uid = uid,
       pwd = pwd,
       dbms.name = dbms.name,
+      attributes = attributes,
       .connection_string = .connection_string)
 
     # perform the connection notification at the top level, to ensure that it's had
@@ -119,8 +124,7 @@ setMethod(
     if (!is.null(getOption("connectionObserver"))) { # nocov start
       addTaskCallback(function(expr, ...) {
         tryCatch({
-          if (is.call(expr) &&
-              as.character(expr[[1]]) %in% c("<-", "=") &&
+          if (rlang::is_call(x = expr, name = c("<-", "=")) &&
               "dbConnect" %in% as.character(expr[[3]][[1]])) {
 
             # notify if this is an assignment we can replay
